"""djangocms-helper - Helpers for django CMS plugin development"""

__version__ = '0.6.0'
__author__ = 'Iacopo Spalletti <i.spalletti@nephila.it>'
__all__ = ['runner']
 
